%function ISR
%
%## @deftypefn   
%+----------------------------------------------------------------------+
%|                          I S R S I G N A L                           |
%|  Integracion y filtro de acelerogramas para obtener desplazamientos. |
%|               Creado por Ing. Gonzalo Torrisi (UNC)                  |
%|                           Diciembre 2006                             |
%|                        Diciembre 2022 (V5.0)                           |
%+----------------------------------------------------------------------+
%
%==========================================================================
%                               H E L P
%                              ---------
%
% El archivo de datos debe contener dos columnas5
% La primera es el vector de tiempos (seg.)
% La segunda es el vector de aceleraciones en %g
%
% El numero de puntos  de datos debe ser por lo menos 3 veces el orden del
% filtro.
% Las demas variables son pedidas en el input luego de proponer un valor.
%
% Las velocidades se entregan en m/s y los desplazamientos en m.
%
% Se cream archivos llamados despla.out, veloc.out, acel.out y otros mas
% que contienen los desplazamientos, velocidades, aceleraciones y otros
% resultados de interes.

%==========================================================================%
% USUARIOS DE OCTAVE DEBEN EJECUTAR LO SIGUIENTE EN LINEA DE COMANDO
%                           pkg load signal
%
%==========================================================================
%
%## @end deftypefn
clear all
clc
disp('  ')
disp('          +----------------------------------------------+')
disp('          |                                              |')
disp('          |             I S R - S I G N A L              |')       
disp('          |        =============================         |')
disp('          |                     v5.0                     |')
disp('          |                                              |')
disp('          |    Integracion y filtro de acelerogramas     |')
disp('          |        para obtener desplazamientos.         |')
disp('          |     CALCULO DE ESPECTROS DE RESPUESTA.       |')
disp('          |                                              |')
disp('          |    Autor: Dr.Ing. Gonzalo Torrisi (UNC)      |')
disp('          |  gonzalo.torrisi@ingenieria.uncuyo.edu.ar    |')
disp('          |            Diciembre 2006 (v1.0)             |')
disp('          |              Abril 2022 (v5.0)               |')
disp('          |                                              |')
disp('          +----------------------------------------------+')
%archivo de datos
%Defino algunas variables que van a ser utilizadas  a lo largo del archivo:
g=9.81;
%pkg load signal
disp('      ')
disp('Se crean archivos de salida de diversos nombres')
disp('Con los resultados de los distintos pasos.')
disp('Ademas, se generan imagenes de los graficos mostrados')
disp('Se recomienda usar Matlab 2019 o superior')

disp(' ');
disp('****************************************************************');
disp('                        ATENCION!!!');
disp('Se van a generar nuevos archivos de imagenes de los graficos');
disp('         Por lo tanto se van a borrar los existentes.');
disp('****************************************************************');
disp(' USUARIOS DE OCTAVE DEBEN EJECUTAR LO SIGUIENTE EN LINEA DE COMANDO');
disp('                           pkg load signal');
disp(' ');
fil=input('Ingrese nombre de archivo de datos: ','s');
EQ=leer_archivo(fil);
disp('Cargando datos...')
esc=1.0;
esc=input('Factor de escala para modificar las aceleraciones ?:');
%if isfile('Registro original.jpg')
if exist('Registro original.jpg', 'file') == 2
    delete *.jpg;
end
%vectores de tiempo y aceleracion
    t=EQ(:,1);
    a=EQ(:,2);
    n=length(t);
    DT=t(3)-t(2);

% el registro original, tal cual se leyo se guarda en el vector a_orig 
a_orig=a*9.81;  %unidades de m/s2
t_orig=t;
%el archivo de trabajo se renombrara "a" cada vez que termine una tarea
PGA=0;
for i=1:n
    if abs(a_orig(i))>PGA
        PGA=abs(a_orig(i));
    end
end
fprintf('\nMaxima aceleracin del registro PGA: %5f g',PGA/g)
fprintf('\nDuracin maxima del registro: %5f s',t(n))  
disp(' ');
if esc ~=1.0
    a=a_orig*esc;
end
v1=0;
d1=0;
a=a_orig;
for i=1:n-1
    DT1    = t(i+1)-t(i);
    v1(i+1)= v1(i)+(a(i+1)+a(i))*DT1/2;
    d1(i+1)= d1(i)+v1(i)*DT1+(2*a(i)+a(i+1))*(DT1^2)/6;
end


figure('Name','Registro original','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
%grafico aceleracion
subplot(3,3,1:3);plot(t,a_orig/g,'-b'),grid, title('aceleracion'),xlabel('tiempo (seg)'),ylabel('aceleracion (%g)')
%grafico velocidades
subplot(3,3,4:6);plot(t,v1,'-b'),grid, title('Velocidades'),xlabel('tiempo (seg)'),ylabel('velocidad (m/s)')
%grafico desplazamientos
subplot(3,3,7:9);plot(t,d1,'-b'),grid, title('desplazamientos'),xlabel('tiempo (seg)'),ylabel('desplazamiento (m)')
print(gcf, '-djpeg', 'Registro original.jpg')

iar=input('Desea calcular la intensidad de Arias y duracion significativa? si=1, no=0:');
if iar==1
%Intensidad de Arias y duracion significativa
    n1=length(t);
    Ia=0;
    Ia=cumsum((a).^2)*DT;
    Ia=Ia*pi/(2*g);
    Iamax=Ia(end);
    Ia=Ia/Iamax;
    timed=t(Ia>=0.05 & Ia<=0.95);
    t_5_95=[timed(1),timed(end)];
    td=timed(end)-timed(1)+DT;
    %%cantidad de cruces por cero
    nu=0;
    for i=1:n1-1
        if a(i)*a(i+1)<0
            nu=nu+1;
        end
    end
    nu=nu/t(n1);
    PD=Iamax*100/(nu*nu);
    rmsacc=rms(a);
    figure('Name','Intensidad de Arias','NumberTitle','off')
    plot(t,Ia*100,'-r'),grid, title('Intensidad de Arias'),xlabel('tiempo (seg)'),ylabel('Intensidad (%)')
    print(gcf, '-djpeg', 'Intensidad de Arias.jpg')
    fprintf('\nLa Intensidad de Arias es= %10f',Iamax);
    fprintf('\nLa Duracion significativa entre el 0.05 y 0.95 es= %5f s',td);
    fprintf('\nEl tiempo inicial es: %5f s',timed(1));
    fprintf('\nEl tiempo final es: %5f s',timed(end));
    fprintf('\nPotencial destructivo: %5f cm.s',PD);   
    fprintf('\nRMSacc: %5f ',rmsacc);      
    disp(' ');   
matres=[ strcat('Intensidad Arias       = ',  num2str(Iamax,'%e'));
         strcat('Duracion significativa = ',  num2str(td,'%e'));
         strcat('Tiempo inicial         = ',  num2str(timed(1),'%e'));
         strcat('Tiempo final           = ',  num2str(timed(end),'%e'));
         strcat('Potencial destructivo  = ',  num2str(PD,'%e'));
         strcat('RMSacc                 = ',  num2str(rmsacc,'%e'))];
matres2(:,1)=t(:);
matres2(:,2)=Ia(:)*100;

fila=fopen('Arias1.out','w');
for i=1:5
  fprintf(fila,'%s\n',matres(i,1:30));
end
fclose(fila); 

 save Arias_curva.out matres2 -ascii -tabs   
    end
dt=DT;
icen=input('Desea centrar el acelerograma? si=1, no=0, ENTER=no :');
if icen==1
    disp('Centrando el acelerograma...')
    sum=0;
    prom=0;
    fprintf('\nLongitud total del registro: %10f s',n*dt)
    disp(' ')
    sum=0;
    for i=1:n
        sum=sum+a(i);
    end
    prom=sum/n;
    for i=1:n
        a(i)=a(i)-prom;
    end
    if a(1)<0 
        for i=1:n
          a(i)=a(i)-a(1);
        end
    elseif a(1)>0
        for i=1:n
            a(i)=a(i)-a(1);
        end    
    end
    sum=0;
    for i=1:n
        sum=sum+a(i);
    end
    prom=sum/n;
    for i=1:n
         a(i)=a(i)-prom;
    end
end
disp('Leido acelerograma...')
disp('Datos leidos OK...')
dt=DT;
a3=a;
t3=t;
izero=input('Desea agregar ceros al final del registro? 1=si, 0=no :');
if izero==1
  t2=t;
  a2=0.0;
  n2=2*n;
  for i=1:n
    t3(i)=t(i);
    t3(i+n)=t(n)+dt*i;
    a3(i)=a(i);
    a3(i+n)=0.0;
  end  
  n=n2;
else
  a3=a;
  t3=t;
  n2=n;
end
a=a3;
t=t3;
n=n2;

figure('Name','Registro de aceleracion','NumberTitle','off')
plot(t,a/g),grid, title('Registro de aceleraciones inicial'),xlabel('Tiempo (seg)'),ylabel('Aceleracion (%g)')
print(gcf, '-djpeg', 'Registro aceleracion inicial.jpg')
v1=0;
v1=dt*cumtrapz(a);
d1=0;
d1=dt*cumtrapz(v1);
%Pregunta y calcula espectro de fourier
ies=input('Desea calcular el espectro de fourier? 1=si, 0=no, ENTER=default :');
if ies==1
disp('Calculando espectro de fourier...')
%    if itype==2
%        dt=input('Ingrese delta T del time history: ');
%        l=(lena-1)*dt;
%        t=0.0:dt:l;
%    end
    dt=t(3)-t(2);
    for j=1:n
        f(j)=j/(dt*n);
    end
    for i=1 :n/2
        frec(i)=f(i);
    end
    y1=fft(a);
    y=abs(fft(a));
    ymax=max(y);
    for i=1:n/2
        amp(i)=y(i)/ymax;
    end
    figure('Name','Espectro de Fourier','NumberTitle','off')
    plot(frec,amp),grid, title('Espectro de fourier'),xlabel('Frecuencia (Hz)'),ylabel('Amplitud')
    print(gcf, '-djpeg', 'Espectro de Fourier.jpg')
    fi = frec(frec>0.25 & frec<20);
    Ci = amp(frec>0.25 & frec<20);
    Tm = ((Ci(:)'.^2)*(1./fi(:)))/(Ci(:)'*Ci(:));
    fprintf('\nPeriodo medio de seal original : %10f s',Tm) ;
    disp(' ');
  
end
cor=true;
fil=true;
corfil=true;
while(corfil)
while(cor)
%%%correccion de linea base
disp('Paso 1...Correccion de linea base inicial.')

% degree of fitting
nd=input('Ingrese orden de ajuste (si orden=0 no se ajusta el registro):');
if nd~=0
% fit a polynomial trend to the acceleration time history
c1 = polyfit(t,a,nd);
aFit = polyval(c1,t);
% Correct the time histories
a_cor=a-aFit;
v_cor = cumtrapz(t,a_cor);
d_cor = cumtrapz(t,v_cor);

figure('Name','Correccin Inicial','NumberTitle','off')
%grafico aceleracion
subplot(3,3,1:3);plot(t,a_cor/g,'-b'),grid, title('aceleracion'),xlabel('tiempo (seg)'),ylabel('aceleracion (g)')
%grafico velocidades
subplot(3,3,4:6);plot(t,v_cor,'-b'),grid, title('Velocidades'),xlabel('tiempo (seg)'),ylabel('velocidad (m/s)')
%grafico desplazamientos
subplot(3,3,7:9);plot(t,d_cor,'-b'),grid, title('desplazamientos'),xlabel('tiempo (seg)'),ylabel('desplazamiento (m)')
print(gcf, '-djpeg', 'Correccion inicial.jpg')
a=a_cor;
end

np=n;
iordlb=input('Ingrese orden de la correccion 0=constante, 1=linear, 2=cuadratica, 3=cubica, 4=ninguna :');
if iordlb<4
    nx=0;
    nx2=0;
    nx3=0;
    nx4=0;
    nx5=0;
    nx6=0;
    xy=0;
    xy2=0;
    xy3=0;
    y1=0;
    np=n;
    af2=0;
    %n=np;
    for i=1:np
      nx=nx+t(i);
      nx2=nx2+t(i)^2;
      nx3=nx3+t(i)^3;
      nx4=nx4+t(i)^4;
      nx5=nx5+t(i)^5;
      nx6=nx6+t(i)^6;
      xy=xy+t(i)*a(i);
      xy2=xy2+t(i)*a(i)*t(i);
      xy3=xy3+t(i)*a(i)*t(i)^2;
      y1=y1+a(i);
    end
    if iordlb==0
        x(1)=y1/n;
        fprintf('\nx(1): %d',x(1));
        for i=1:np
             af2(i)=x(1);
        end
    elseif iordlb==1
        M=[n nx
           nx nx2];
        y=[y1
           xy];
        x=inv(M)*y;
        fprintf('\nx(1), x(2): %d, %d',x(1),x(2));
        for i=1:np
            af2(i)=x(1)+x(2)*t(i);
        end
    elseif iordlb==2
      M=[n nx nx2 
         nx nx2 nx3 
         nx2 nx3 nx4];
      y=[y1
         xy
         xy2];
      x=inv(M)*y;
      fprintf('\nx(1), x(2), x(3): %d, %d, %d',x(1),x(2),x(3));
      for i=1:np
           af2(i)=x(1)+x(2)*t(i)+x(3)*t(i)^2;
      end
   elseif iordlb==3 
      M=[n nx nx2 nx3
         nx nx2 nx3 nx4
         nx2 nx3 nx4 nx5
         nx3 nx4 nx5 nx6];
      y=[y1
         xy
         xy2 
         xy3];
      x=inv(M)*y;
      fprintf('\nx(1), x(2), x(3), x(4): %d, %d, %d, %d',x(1),x(2),x(3),x(4));
      for i=1:np
         af2(i)=x(1)+x(2)*t(i)+x(3)*t(i)^2+x(4)*t(i)^3;
      end
    end

    acnew=0;
    vel=0;
    des=0;
    acnew=a-af2';

    for i=1:n-1
        DT1    = t(i+1)-t(i);
        vel(i+1)= vel(i)+(acnew(i+1)+acnew(i))*DT1/2;
        des(i+1)= des(i)+vel(i)*DT1+(2*acnew(i)+acnew(i+1))*(DT1^2)/6;
    end
    figure('Name','Correccin de linea base','NumberTitle','off')
%grafico aceleracion
subplot(3,3,1:3);plot(t,acnew,'-b'),grid, title('aceleracion'),xlabel('tiempo (seg)'),ylabel('aceleracion (g)')
%grafico velocidades
subplot(3,3,4:6);plot(t,vel,'-b'),grid, title('Velocidades'),xlabel('tiempo (seg)'),ylabel('velocidad (m/s)')
%grafico desplazamientos
subplot(3,3,7:9);plot(t,des,'-b'),grid, title('desplazamientos'),xlabel('tiempo (seg)'),ylabel('desplazamiento (m)')
print(gcf, '-djpeg', 'Correccion linea base.jpg')
else
   acnew=a;   
end
a=acnew;
disp(' ');
ask1=input('corrige de nuevo (1) o sigue (2) ?:');
if ask1==1
  cor=true;
else
  cor=false;
end
end

  while(fil)
disp(' ');
disp('Paso 2: Filtrado de frecuencias.');
iopfil2=input('Desea realizar la eliminacion de algunas frecuencias (1) o filtrado general (2)? :');
if iopfil2==1
    nfre=input('Ingrese la cantidad de frecuencias a eliminar n= ');
    fprintf('\nPara cada una de las %d frecuencias, ingrese el valor de la frecuencia del espectro de fourier \n',nfre);
    for ifre=1:nfre
        fprintf('\nFrecuencia numero %d : \n',ifre);
        fre1=input('Frecuencia a eliminar (Hz) = ');
        mult1=input('Multiplicador de escala para la frecuencia m= ');
        frec_el(ifre)=fre1;
    end
     for j=1:n
        f(j)=j/(dt*n);
    end
    for i=1 :n/2
        frec(i)=f(i);
    end
    y1=fft(a);
    for ifre=1:nfre
        for ii=1:n/2
            if (abs(abs(frec(ii))-frec_el(ifre))<0.001)
                y1(ii)=y1(ii)*mult1;
                disp('corregida frecuencia...')
            end
        end
    end

    y=abs(fft(a));
    ymax=max(y);
      
    for i=1:n/2
        amp(i)=y(i)/ymax;
        amp2(i)=abs(y1(i))/ymax;
    end
    figure('Name','Espectro de Fourier','NumberTitle','off')
    plot(frec,amp,frec,amp2),grid, title('Espectro de fourier modificado'),xlabel('Frecuencia (Hz)'),ylabel('Amplitud')
    print(gcf, '-djpeg', 'Espectro de Fourier modificado.jpg')
    aft=ifft(y1);
    figure('Name','Registro modificado','NumberTitle','off')
    plot(t,a,t,aft),grid, title('Aceleraciones modificadas'),xlabel('Tiempo (seg)'),ylabel('Aceleracion (g)')
    print(gcf, '-djpeg', 'aceleraciones modificadas.jpg')
    velnew=0;
    velnew=dt*cumtrapz(aft);
    des=0;
    des=dt*cumtrapz(velnew);  


else
    iopfil=1;
%iopfil=input('Desea realizar un filtro de frecuencias? si=1, no=0 :');
if iopfil==1
    num=int16(n/3);
    num2=num-2;
    if num2 > 5000
       orden_supuesto=5000;
    else
       orden_supuesto=num-2;
    end
    fprintf('\nOrden maximo del filtro: %d',orden_supuesto)
    disp(' ')
    nor=input('Ingrese orden del filtro: ');
    ord=nor;
%%rutina de correccion e integracion
    fs=1/DT;
    disp(' ')
    fc1=input('Ingrese frecuencia de corte inicial en Hz: ');
    fc2=input('Ingrese frecuencia de corte final en Hz: ');
    disp('Paso 2.1 ...Filtrado inicial.')
     itf=input('Tipo de filtro: fir1 (1) o butter (2)? :');
     if itf==1
      b=fir1(ord,[fc1 fc2]/(fs/2));
      d=1;
     else
%        itf=2;
         if ord>10
             ord=10;
         end
         [b,d]=butter(ord,[fc1 fc2]/(fs/2));
     end

 figure('Name','Filtro usado','NumberTitle','off')
   freqz(b,d,512,fs)
    title('Filtro utilizado')
%cambio unidades de aceleracion de %g a m/s2
    disp('Paso 2.2 ...Cambio de unidades.')
    disp('Paso 2.3 ...Filtrado de aceleraciones.')
   aft = filtfilt(b,d,a);
    disp('Paso 2.4 ...Integracion de aceleraciones para obtener velocidades')
    vft=cumtrapz(t,aft);
    disp('Paso 2.5 ...Filtrado de velocidades.')
    vftf=filtfilt(b,d,vft);
    disp('Paso 2.6 ...Integracion de velocidades para obtener desplazamientos.')
    dft=cumtrapz(t,vftf);
    disp('  ')
    velnew=vftf;
    des=dft;
    for j=1:n
        f(j)=j/(dt*n);
    end
    for i=1 :n/2
        frec(i)=f(i);
    end
    y1=abs(fft(aft));
    ymax1=max(y1);
    y=abs(fft(a));
    ymax=max(y);
    ym=ymax;
    if ymax1>ym
        ym=ymax1;
    end
    for i=1:n/2
        amp(i)=y(i)/ym;
        amp1(i)=y1(i)/ym;
    end
    xx1=[ fc1  fc1];
    xx2=[ fc2  fc2];
    yy1=[0.0  1.0 ];
    yy2=[0.0  1.0 ];   
    figure('Name','Espectro de Fourier corregido (normalizado a 1)','NumberTitle','off')
    plot(frec,amp,'--b',frec,amp1,'-r',xx1,yy1,'-g',xx2,yy2,'-g'),grid, title('Espectro de fourier'),xlabel('Frecuencia (Hz)'),ylabel('Amplitud');legend('- : Original','- : Modificada','- : f1','- : f2')
print(gcf, '-djpeg', 'Expectro Fourier corregido.jpg')
    fi = frec(frec>0.25 & frec<20);
        Ci = amp1(frec>0.25 & frec<20);
        Tm1 = ((Ci(:)'.^2)*(1./fi(:)))/(Ci(:)'*Ci(:));
        fprintf('\nPeriodo medio de seal filtrada : %10f s',Tm1) ;
        disp(' ');
else
    velnew=0;
    velnew=dt*cumtrapz(a);
    des=0;
    des=dt*cumtrapz(velnew);  
    aft=a;
end 
end
%%a=aft;
fprintf('\n');
disp('Paso 3...Almacenamiento.')
disp(' ')
disp(' ')
%Creo matrices de resultados
disp('Guardando resultados...')
R1(:,1)=t;
R1(:,2)=des;
R2(:,1)=t;
R2(:,2)=velnew;
R3(:,1)=t;
R3(:,2)=aft;
%CREO GRAFICOS
figure('Name','Aceleraciones-Velocidades-Desplazamientos','NumberTitle','off')
%grafico aceleracion
subplot(3,3,1:3);plot(t,aft/g,'-r',t,a/g,'--b'),grid, title('aceleracion'),xlabel('tiempo (seg)'),ylabel('aceleracion (g)');
legend('- : Modificada','- : Original')
%grafico velocidades
subplot(3,3,4:6);plot(t,velnew,'-r',t,v1,'--b'),grid, title('Velocidades'),xlabel('tiempo (seg)'),ylabel('velocidad (m/s)');legend('- : Modificada','- : Original')
%grafico desplazamientos
subplot(3,3,7:9);plot(t,des,'-r',t,d1,'--b'),grid, title('desplazamientos'),xlabel('tiempo (seg)'),ylabel('desplazamiento (m)');legend('- : Modificada','- : Original')
print(gcf, '-djpeg', 'AVD.jpg')
%grafico respuesta
figure('Name','Registros corregidos','NumberTitle','off')
%grafico aceleracion
subplot(3,3,1:3);plot(t,aft/g,'-r'),grid, title('Aceleracion corrediga'),xlabel('tiempo (seg)'),ylabel('aceleracion (g)')
%grafico velocidades
subplot(3,3,4:6);plot(t,velnew,'-r'),grid, title('Velocidades corregidas'),xlabel('tiempo (seg)'),ylabel('velocidad (m/s)')
%grafico desplazamientos
subplot(3,3,7:9);plot(t,des,'-r'),grid, title('Desplazamientos corregidos'),xlabel('tiempo (seg)'),ylabel('desplazamiento (m)')
print(gcf, '-djpeg', 'AVD-corr.jpg')
figure('Name','Desplazamiento corregido','NumberTitle','off')
plot(t,des),grid,title('Desplazamientos Corregidos'),xlabel('tiempo (seg)'),ylabel('desplazamiento (m)')
print(gcf, '-djpeg', 'Desplazamiento.jpg')
save acel.out R3 -ascii -tabs
save despla.out R1 -ascii -tabs
save veloc.out R2 -ascii -tabs
disp(' ');
ask2=input('filtra de nuevo (1) o sigue (2) ?:');
if ask2==1
  fil=true;
else
  fil=false;
end

end
disp(' ');
ask3=input('Corrige y/o filtra de nuevo (1) o sigue (2) ?:');
if ask3==1
  corfil=true;
else
  corfil=false;
end
end
 ies=input('Quiere calcular los espectros de respuesta de los registros corregidos y no corregido? si=1, no=0: ');
 if ies==1
  Pmin=input('Ingrese periodo inicial para calcular el espectro (>0.0): ');
  Pmax=input('Ingrese periodo final para calcular el espectro : ');
  Pdel=input('Ingrese incremento de periodo (deltaT>0.0): ');
   nt=int16((Pmax-Pmin)/Pdel+1);
  fprintf('\nEl numeor de puntos a calcular es :! %10f ',nt); 
  s=0.05;
  fprintf('\nLos espectros se calculan para un amortiguamiento de : %10f ',s) ;  
  disp(' ' );
  disp('Calculando espectros...');
 
    P=Pmin:Pdel:Pmax;
    AG1=a_orig*esc;
    AG2=aft*esc;
    N2=max(size(P));
    Ae1=0;
    Ve1=0;
    De1=0;
    N1=max(size(t));
for i=1:N2
    F(i)=1/P(i);
    w=2*pi/P(i);
    m=1;
    k=w*w*m;
    c=s*2*sqrt(k*m);
    [De1,Ve1,Ae1] = NewmarkLineal(N1,t,-AG1*m,m,c,k,1/2,1/4);
    SDo(i)=max(abs(De1));
    SVo(i)=max(abs(Ve1));
    SAo(i)=max(abs(Ae1+AG1'));
    PSVo(i)=SDo(i)*w;
    PSAo(i)=SDo(i)*w*w;
end

    N1=max(size(t));
for i=1:N2
    F(i)=1/P(i);
    w=2*pi/P(i);
    m=1;
    k=w*w*m;
    c=s*2*sqrt(k*m);
    [De2,Ve2,Ae2] = NewmarkLineal(N1,t,-AG2*m,m,c,k,1/2,1/4);
    SDc(i)=max(abs(De2));
    SVc(i)=max(abs(Ve2));
    SAc(i)=max(abs(Ae2+AG2'));
    PSVc(i)=SDc(i)*w;
    PSAc(i)=SDc(i)*w*w;
end
     
figure('Name','Espectros de respuesa de registros sin corregir','NumberTitle','off')
%grafico aceleracion
subplot(3,3,1:3);plot(P,SAo/g,'-r',P,PSAo/g,'--r'),grid, title('Espectro de aceleraciones'),xlabel('Periodo (seg)'),ylabel('Pseudo Aceleracion (g)');legend('- : Espectro','- :PseudoEspectro')
%grafico velocidades
subplot(3,3,4:6);plot(P,SVo,'-b',P,PSVo,'--b'),grid, title('Espectro de velocidades'),xlabel('Periodo (seg)'),ylabel('Velocidades (m/s)');legend('- : Espectro','- :PseudoEspectro')
%grafico desplazamientos
subplot(3,3,7:9);plot(P,SDo,'-g'),grid, title('Espectro de desplazamientos'),xlabel('Periodo (seg)'),ylabel('Desplazamiento (m)');legend('- : Espectro')
print(gcf, '-djpeg', 'Espectro original.jpg')

figure('Name','Espectros de respuesa de registros corregidos','NumberTitle','off')
%grafico aceleracion
subplot(3,3,1:3);plot(P,SAc/g,'-r',P,PSAc/g,'--r'),grid, title('Espectro de aceleraciones'),xlabel('Periodo (seg)'),ylabel('Pseudo Aceleracion (g)');legend('- : Espectro','- :PseudoEspectro')
%grafico velocidades
subplot(3,3,4:6);plot(P,SVc,'-b',P,PSVc,'--b'),grid, title('Espectro de velocidades'),xlabel('Periodo (seg)'),ylabel('Velocidades (m/s)');legend('- : Espectro','- :PseudoEspectro')
%grafico desplazamientos
subplot(3,3,7:9);plot(P,SDc,'-g'),grid, title('Espectro de desplazamientos'),xlabel('Periodo (seg)'),ylabel('Desplazamiento (m)');legend('- : Espectro')
print(gcf, '-djpeg', 'Espectro corregido.jpg')

figure('Name','Espectros de respuesa de registros corregidos y sin corregir','NumberTitle','off')
%grafico aceleracion
subplot(3,3,1:3);plot(P,SAc/g,'-r',P,SAo/g,'--r'),grid, title('Espectro de aceleraciones'),xlabel('Periodo (seg)'),ylabel('Pseudo Aceleracion (g)');legend('- : Corregido','- : Sin corregir')
%grafico velocidades
subplot(3,3,4:6);plot(P,SVc,'-b',P,SVo,'--b'),grid, title('Espectro de velocidades'),xlabel('Periodo (seg)'),ylabel('Velocidades (m/s)');legend('- : Corregido','- : Sin corregir')
%grafico desplazamientos
subplot(3,3,7:9);plot(P,SDc,'-g',P,SDo,'--g'),grid, title('Espectro de desplazamientos'),xlabel('Periodo (seg)'),ylabel('Desplazamiento (m)');legend('- : Corregido','- : Sin corregir')
 print(gcf, '-djpeg', 'Espectros comparados.jpg')
 

disp('Guardando espectros...')
Eo(:,1)=P;
Eo(:,2)=SDo;
Eo(:,3)=SVo;
Eo(:,4)=PSVo;
Eo(:,5)=SAo/g;
Eo(:,6)=PSAo/g;
Ec(:,1)=P;
Ec(:,2)=SDc;
Ec(:,3)=SVc;
Ec(:,4)=PSVc;
Ec(:,5)=SAc/g;
Ec(:,6)=PSAc/g;
save Esp_orig.out Eo -ascii -tabs
save Esp_cor.out Ec -ascii -tabs
end
disp('PROGRAMA FINALIZADO')

